@@ -339,13 +339,13 @@ class FargateToStepfunctionsProps:
         :param vpc_props: Optional custom properties for a VPC the construct will create. This VPC will be used by the new Fargate service the construct creates (that's why targetGroupProps can't include a VPC). Providing both this and existingVpc is an error. A Step Functions Interface endpoint will be included in this VPC. Default: - A set of defaults from vpc-defaults.ts: DefaultPublicPrivateVpcProps() for public APIs and DefaultIsolatedVpcProps() for private APIs.
         '''
         if isinstance(state_machine_props, dict):
-            state_machine_props = StateMachineProps(**state_machine_props)
+            state_machine_props = aws_cdk.aws_stepfunctions.StateMachineProps(**state_machine_props)
         if isinstance(cluster_props, dict):
-            cluster_props = ClusterProps(**cluster_props)
+            cluster_props = aws_cdk.aws_ecs.ClusterProps(**cluster_props)
         if isinstance(log_group_props, dict):
-            log_group_props = LogGroupProps(**log_group_props)
+            log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
         if isinstance(vpc_props, dict):
-            vpc_props = VpcProps(**vpc_props)
+            vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
         if __debug__:
             type_hints = typing.get_type_hints(FargateToStepfunctionsProps.__init__)
             check_type(argname="argument public_api", value=public_api, expected_type=type_hints["public_api"])
